import plotly.graph_objects as go
import plotly.io as pio

pio.templates["draft"] = go.layout.Template(
    layout_annotations=[
        dict(
            name="draft watermark",
            text="DRAFT",
            textangle=-30,
            opacity=0.1,
            font=dict(color="black", size=100),
            xref="paper",
            yref="paper",
            x=0.5,
            y=0.5,
            showarrow=False,
        )
    ]
)


import math
import numpy as np

# useful functions
aval = [0.5, 1, 2, 4]
bval = [150, 120, 80, 50]


def floor_freq(l, EI, m):
    f1 = (math.pi/2/l**2)*math.sqrt(EI/m)
    return f1


def vel(f1, b, l, m, EIl, EIt):
    n40 = math.pow(((40/f1)**2-1.0)*((b/l)**4)*(EIl/EIt), 0.25)
    print(f"n40 = {n40}")
    v = 4*(0.4+0.6*n40)/(m*b*l+200)
    return v


def b_from_a(a):
    return np.interp(a, aval, bval)


def a_from_b(b):
    return np.interp(b, np.flip(bval), aval)


def vlim(f1, b, damp):
    return math.pow(b, f1*damp-1.0)


import numpy as np
import math
from . import utils


def iscracked_annexLL(fctm: float, fcm: float, 
                sigxx: float, sigyy: float, sigzz: float, 
                sigxy: float, sigyz: float, sigzx: float) -> bool:
    """Checks if the point is cracked using expression (LL.101) of Annex LL of EN 1992-2:2005.
    Author. Paulo Cachim (2022)

    Args:
        fctm (float): mean tensile strength of concrete
        fcm (float): mean comprerssive strength of concrete
        sigxx (float): stress xx
        sigyy (float): stress yy
        sigzz (float): stress zz
        sigxy (float): stress xy
        sigyz (float): stress yz
        sigzx (float): stress zx

    Returns:
        bool: True if cracked, False otherwise
    """
    # Calculate stress invariants
    invar = utils.stress.invariants(sigxx, sigyy, sigzz, sigxy, sigyz, sigzx)
    I1 = invar[0] / fcm
    J2 = invar[1] / fcm / fcm
    cos3t = invar[8]
    
    # Calculate auxiliary parameters
    k = fctm/fcm
    c1 = 1.0/(0.7*k**0.9)
    c2 = 1.0 - 6.8*(k-0.07)**2
    alpha = 1.0/(9.0*k**1.4)
    beta = 1.0/(3.7*k**1.1)
    ang = math.acos(abs(c2 * cos3t))/3.0
    lamb = c1 * math.cos(ang) if cos3t >= 0 else c1 * (math.pi/3.0-ang)
    
    # Calculate cracking condition (>0 cracked; <0 uncracked)
    crack = alpha*J2 + lamb*math.sqrt(J2) + beta*I1 - 1.0
    
    # Return cracked stated (True: cracked: False: uncracked)
    return True if crack > 0 else False



from .. import db
db = db

from .shear import calc_asws
from .shear import calc_vrd
from .shear import calc_vrdc

from . import beam
from .beam import get_bend_params
from .beam import calc_mrd
from .beam import calc_asl
from .beam import calc_vrdc
from .beam import calc_asws
from .beam import calc_vrd
from .beam import RCBeam

from .shell import calc_reinf_shell
from .shell import calc_reinf_plane

from . import shear
from . import shell





from .. import db

from .. import utils

from . import spectrum
from .spectrum import get_spectrum_parameters
from .spectrum import get_spectrum
from .spectrum import spectrum_ec8
from .spectrum import spectrum_user
from .spectrum import write_spectrum_ec8
from .spectrum import draw_spectrum_ec8



from .. import db

from .. import utils

from . import material
from .material import beta_cc
from .material import beta_ce
from .material import cemprops
from .material import calc_creep_coef
from .material import calc_shrink_strain

from . import fire
from . import crack
from .crack import iscracked_annexLL

from . import uls
from .uls.shear import calc_asws
from .uls.shear import calc_vrd
from .uls.shear import calc_vrdc
from .uls.beam import get_bend_params
from .uls.beam import calc_mrd
from .uls.beam import calc_asl
from .uls.shell import calc_reinf_shell




# eurocodepy

"""Provide several functions to help designers working with Eurocodes.

This module allows the user to make mathematical calculations.

The module contains the following functions:

- `db`: Returns the database of the Eurocodes.
- `ec1`: Returns the difference of two numbers.
- `ec2` - Returns the product of two numbers.
- `ec5` - Returns the quotient of two numbers.
- `ec8` - Returns the quotient of two numbers.
"""

# print ("This is eurocodepy v0.1.20")

from . import ec1
from . import ec2
from . import ec5
from . import ec8
from . import utils

from .db import db
from .db import dbase
from .db import Materials

from .db import Bolts
from .db import BoltClasses
from .db import BoltDiameters

from .db import Concrete
from .db import ConcreteClasses
from .db import ConcreteParams

from .db import Prestress
from .db import PrestressClasses
from .db import PrestressParams

from .db import Reinforcement
from .db import ReinforcementBars
from .db import ReinforcementClasses
from .db import ReinforcementParams

from .db import Steel
from .db import SteelClasses
from .db import SteelParams

from .db import SteelProfiles

from .utils import stress

RECTANGULAR = 0
CIRCULAR = 1
TSECTION = 2
LSECTION = 3
INVTSECTION = 4
POLYGONAL = 5


